@@ -406,6 +406,14 @@ hangul_ic_filter_2(HangulInputContext *hic, wchar_t ch)
     wchar_t jong;
     wchar_t combined;
 
+    if (!hangul_is_choseong(ch) && !hangul_is_jungseong(ch) &&
+	!hangul_is_jongseong(ch) && ch > 0) {
+	hangul_ic_save_commit_string(hic);
+	hangul_ic_append_commit_string(hic, ch);
+	hangul_ic_save_preedit_string(hic);
+	return true;
+    }
+
     if (hic->buffer.jongseong) {
 	if (hangul_is_choseong(ch)) {
 	    jong = hangul_choseong_to_jongseong(ch);
